==> tdm_2.1.1.tar.gz: tdm/R/all.Oxtirms.R <==
all.Oxtirms<-function(){
     cat("\n")                                                                      
     cat("-----------------------------------------------------------\n")
     cat("    --Oxtriphylline IR input data information--            \n")
     note_for_Theirss_input()
     cat("-----------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     OxtirMSpar<-data.frame(subject=c(1,2),Gender=c(0),age=c(0),ht=c(0),CHF=c(0),smoke=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     OxtirMSpar<-edit(OxtirMSpar)
     OxtirMSpar<-ymscheck(OxtirMSpar)
     cat("\n")
     Oxtir.ms(length(OxtirMSpar$subject),OxtirMSpar$c,OxtirMSpar$tau,OxtirMSpar$ts,OxtirMSpar$D,OxtirMSpar$ht,OxtirMSpar$age,OxtirMSpar$smoke,OxtirMSpar$Gender,OxtirMSpar$CHF)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     cat("-----------------------------------------------------------\n")
     cat("    --Oxtriphylline IR output data information--           \n")
     note_for_Theirss_output()
     cat("-----------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     C<-TheIRsscpr(0.65,OxtirMSpar$D,OxtirMSpar$tau,OxtirMSpar$ts)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(0.65,OxtirMSpar$D,OxtirMSpar$tau,r)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output2<-coutput
     show(coutput)
     C<-TheIRsscpr(0.65,OxtirMSpar$D,OxtirMSpar$tau,OxtirMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output3<-coutput
     show(coutput)     
     cat("\n")   
     cal.again()                   
}

==> tdm_2.2.2.tar.gz: tdm/R/all.Oxtirms.R <==
all.Oxtirms<-function(){
     cat("\n")                                                                      
     cat("-----------------------------------------------------------\n")
     cat("    --Oxtriphylline IR input data information--            \n")
     note_for_Theirss_input()
     cat("-----------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     OxtirMSpar<-data.frame(subject=c(1,2),Gender=c(0),age=c(0),ht=c(0),CHF=c(0),smoke=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     OxtirMSpar<-edit(OxtirMSpar)
##     OxtirMSpar<-ymscheck(OxtirMSpar)
     cat("\n")
     Oxtir.ms(length(OxtirMSpar$subject),OxtirMSpar$c,OxtirMSpar$tau,OxtirMSpar$ts,OxtirMSpar$D,OxtirMSpar$ht,OxtirMSpar$age,OxtirMSpar$smoke,OxtirMSpar$Gender,OxtirMSpar$CHF)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     cat("-----------------------------------------------------------\n")
     cat("    --Oxtriphylline IR output data information--           \n")
     note_for_Theirss_output()
     cat("-----------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     C<-TheIRsscpr(0.65,OxtirMSpar$D,OxtirMSpar$tau,OxtirMSpar$ts)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(0.65,OxtirMSpar$D,OxtirMSpar$tau,r)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output2<-coutput
     show(coutput)
     C<-TheIRsscpr(0.65,OxtirMSpar$D,OxtirMSpar$tau,OxtirMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output3<-coutput
     show(coutput)     
     cat("\n")   
     cal.again()                   
}
